@@ -144,10 +144,10 @@ class MetadataRepository:
     def exists(self) -> bool:
         return self.table_client.exists(self.metadata_table_name)
 
-    def record_failure(self, request_id, e: Exception):
+    def record_failure(self, request_id, e: Exception, worker_name):
         trace = traceback.format_exc()[:MAX_PROP_SIZE]
         error = str(e)[:MAX_PROP_SIZE]
-        entity = {"PartitionKey": self.worker_name, "RowKey": request_id, "FailureMessage": error, "StackTrace": trace}
+        entity = {"PartitionKey": worker_name, "RowKey": request_id, "FailureMessage": error, "StackTrace": trace}
         self.table_client.insert_entity(self.failure_table, entity)
 
     def record_segment_failures(self, request_id, worker_name, failures):
@@ -300,7 +300,7 @@ class Worker:
                 self._process_raw_request(metadata, func)
         except Exception as e:
             self.metadata_repository.record_request_failure(metadata, e)
-            self.metadata_repository.record_failure(request_id, e)
+            self.metadata_repository.record_failure(request_id, e, self.worker_name)
 
     def process_poison_messages(self):
         try:
